@@ -6,12 +6,14 @@ __all__ = []
 from .version import __version__
 
 import sys
+__pyversion__ = sys.version_info[0]
 
 from .utils.Config import _Config
 config = _Config()
 log_ = config.log_
 log_.message('Starting PyNeb version %s' % __version__, calling='PyNeb')
 
+
 if sys.version_info[0:2] < (2, 6):
     log_.warn('Python version >= 2.6 needed, seems you have {0}'.format(sys.version_info), calling='PyNeb')
 try:
@@ -24,7 +26,7 @@ except:
 from .utils.manage_atomic_data import _ManageAtomicData
 atomicData = _ManageAtomicData()
 
-atomicData.defaultDict = 'PYNEB_14_03'
+atomicData.defaultDict = 'PYNEB_17_01'
 atomicData.resetDataFileDict()
 
 from .core.pynebcore import Atom, RecAtom, getAtomDict, getRecEmissivity, EmissionLine, Observation, \
@@ -41,3 +43,12 @@ from .extinction.red_corr import RedCorr
 
 log_.message('PyNeb ready.', calling='PyNeb')
 log_.timer('Starting PyNeb version %s' % __version__, quiet=True, calling='PyNeb')
+
+__info__ = """PyNeb version: {}.
+PyNeb is cited using: Luridiana, V.; Morisset, C.; Shaw, R. A. 2015, A&A, 573, 42
+bibcode: 2015A&A...573A..42L
+Default data dictionary: {}. This set of data can be changed by the user. 
+Do not forget to cite the papers corresponding to the atomic data you are using.
+PyNeb website: https://pypi.python.org/pypi/PyNeb
+PyNeb discussion and hotline group email: pyneb@googlegroups.com
+""".format(__version__, atomicData.defaultDict)
\ No newline at end of file
