@@ -73,7 +73,7 @@ LINE_LABEL_LIST['Fe3'] = ['4009A', '4659A', '4668A', '4701A', '4734A', '4755A',
                           '3323A', '3335A', '3355A', '3357A', '3366A', '3371A', '3406A', '4046A', '4080A', '4097A', 
                           '4607A', '4770A', '4778A', '9701A', '9960A', '5440A', '6096A']
 LINE_LABEL_LIST['Fe4'] = ['4491A', '5685A', '5735A', '6740A']
-LINE_LABEL_LIST['Fe5'] = ['3783A', '3795A', '3829A', '3891A', '3895A', '3911A', '4071A', '4181A', '4227A']
+LINE_LABEL_LIST['Fe5'] = ['3783A', '3795A', '3822A', '3891A', '3895A', '3911A', '4071A', '4181A', '4227A']
 LINE_LABEL_LIST['Fe6'] = ['3556A', '3929A', '5146A', '5176A', '5278A', '5335A', '5370A', '5424A', '5427A', '5485A', '5631A', '5677A']
 LINE_LABEL_LIST['Fe7'] = ['5159A', '5276A', '5721A', '6087A']
 LINE_LABEL_LIST['K4'] = ['6102A', '6796A', '7109A', '2594A', '2711A', '2760A', '4511A', '6.0m', '4.3m', '15.4m']
@@ -109,6 +109,12 @@ LINE_LABEL_LIST['O1'] = ['6300A', '6364A', '6392A', '2959A', '2973A', '2979A', '
 LINE_LABEL_LIST['O2'] = ['3729A', '3726A', '2470A', '7319A','7320A', '7330A', '7331A', '2470A', '834A', '1075A', 
                          '1260A', '833A', '1073A', '1258A', '833A', '1072A', '1256A', '499.3m', '5023.7m', '61.3m', 
                          '40.7m', '121.3m']
+LINE_LABEL_LIST['O2r'] = ['4638.86A', '4641.81A', '4649.13A', '4650.84A', '4661.63A', '4673.73A', '4676.23A', 
+                          '4696.35A', '4317.14A', '4336.86A', '4345.56A', '4349.43A', '4366.89A', '4414.90A', 
+                          '4416.97A', '4069.62A', '4069.88A', '4072.15A', '4075.86A', '4078.84A', '4085.11A', 
+                          '4092.93A', '4590.97A', '4596.18A', '4121.46A', '4132.80A', '4153.30A', '4104.99A', 
+                          '4110.79A', '4119.22A', '4120.28A', '4185.44A', '4189.79A', '4087.15A', '4089.29A', 
+                          '4095.64A', '4097.26A', '4275.55A', '4282.96A']
 LINE_LABEL_LIST['O3'] = ['4931A', '4959A', '5007A', '2315A', '2321A', '2331A', '4363A', '1658A', '1661A', '1666A', 
                          '2497A', '5833A', '88.3m', '32.6m', '51.8m']
 LINE_LABEL_LIST['O4'] = ['1400A', '1407A', '1397A', '1405A', '1394A', '1401A', '788A', '1801A', '1806A', '1812A', 
