@@ -381,7 +381,7 @@ class _ManageAtomicData(object):
     def setDataFile(self, data_file=None, atom=None, data_type=None):
         """
         Associate an atomic data file to an atom and a type of data, which is one of 
-            ('atom', 'coll', 'rec').
+            ('atom', 'coll', 'rec', 'func').
 
         Usage:
             pn.atomicData.setDataFile('cl_iii_atom_M83-KS86.fits')
@@ -406,7 +406,7 @@ class _ManageAtomicData(object):
         if data_type is None:
             strs = re.split(r'[_.]+',data_file)
             data_type = strs[2]
-        if data_type not in ('atom', 'coll', 'rec', 'trc'):
+        if data_type not in ('atom', 'coll', 'rec', 'trc', 'func'):
             self.log_.error('{0} is not a valid type'.format(data_type))
             return None
         if elem not in ELEM_LIST:
@@ -423,7 +423,9 @@ class _ManageAtomicData(object):
                     del self._RecombData[atom]
             self.log_.message('Adding {0} {1} data for {2}'.format(data_file, data_type, atom), calling=self.calling)
         else:
-            self.log_.error('Unknown file {0} or corresponding File path not included in list. Run addDataFilePath first'.format(data_file),
+            av_data = self.getAllAvailableFiles(atom, data_type)
+            self.log_.error("""Unknown file {0} or corresponding File path not included in list. 
+You may mean one of these files: {1}""".format(data_file, av_data),
                            calling=self.calling)
         if (atom == 'H1') and ('H1' in pn.atomicData._RecombData):
             del pn.atomicData._RecombData['H1']
@@ -447,8 +449,8 @@ class _ManageAtomicData(object):
         if (type(at_set) == list) or (type(at_set) == tuple):
             at_dict = {}
             for item in at_set:
-                atom = pn.utils.misc.parseAtom(item)[0]
-                spec = pn.utils.misc.parseAtom(item)[1]
+                atom = parseAtom(item)[0]
+                spec = parseAtom(item)[1]
                 if spec is '':
                     for ispec in SPEC_LIST:
                         try:
@@ -600,33 +602,35 @@ def readNIST(NISTfile,NLevels=None):
                     delimiter = '|', names = 'conf, term, J, energy, ref', 
                     dtype=('a23', 'a9', 'a4', 'float', 'a10'), autostrip=True,
                     converters = {'energy':extract_flt, 'J':bs, 'conf':bs, 'term': bs, 'ref':bs})
-    data = data[data['J'] != '']
-    previous_ref = ''
-    previous_conf = ''
-    previous_term = ''
+    mask = data['J'] != bs('')
+    data = data[mask]
+    previous_ref = bs('')
+    previous_conf = bs('')
+    previous_term = bs('')
     for d in data:
-        if d['conf'] == '':
+        if d['conf'] == bs(''):
             d['conf'] = previous_conf
         else:
             previous_conf = d['conf']
-        if d['term'] == '':
+        if d['term'] == bs(''):
             d['term'] = previous_term
         else:
             previous_term = d['term']
-        if d['ref'] == '':
+        if d['ref'] == bs(''):
             d['ref'] = previous_ref
         else:
             previous_ref = d['ref']
-        if '?' in d['J']:
-            d['J'] = d['J'].split('?')[0]
-        if d['J'] == '':
+            
+        if bs('?') in d['J']:
+            d['J'] = bs(d['J']).split('?')[0]
+        if d['J'] == bs(''):
             d['J'] = 0.
-        elif '/' in d['J']:
-            d['J'] = '{0:.1f}'.format(float(d['J'].split('/')[0]) / float(d['J'].split('/')[1]))
-        elif ',' in d['J']:
-            d['J'] = '{0:.1f}'.format(float(d['J'].split(',')[0]))
+        elif bs('/') in d['J']:
+            d['J'] = '{0:.1f}'.format(float(bs(d['J']).split('/')[0]) / float(bs(d['J']).split('/')[1]))
+        elif bs(',') in d['J']:
+            d['J'] = '{0:.1f}'.format(float(bs(d['J']).split(',')[0]))
         else:
-            d['J'] = '{0:.1f}'.format(float(d['J']))
+            d['J'] = '{0:.1f}'.format(float(bs(d['J'])))
            
     data = data[data['energy'].argsort()]
     data = data.astype([('conf', 'a23'), ('term', 'a9'), ('J', 'float'), ('energy', 'float'), ('ref', 'a10')])
